@@ -8,7 +8,8 @@ use Web::Sitemap;
 use IO::Uncompress::Gunzip qw/gunzip $GunzipError/;
 use Encode qw(decode);
 
-sub _get_test_file_contents {
+sub _get_test_file_contents
+{
 	my ($name) = @_;
 
 	ok -f $name, "file exists";
@@ -25,21 +26,34 @@ sub _get_test_file_contents {
 	return $contents;
 }
 
-sub test_file {
+
+# unify line endings
+sub _ule($)
+{
+	my $string = shift;
+	$string =~ s{\r\n}{\n}g;
+
+	return $string;
+}
+
+sub test_file
+{
 	my ($name, $expected) = @_;
 
 	my $contents = _get_test_file_contents($name);
-	is $contents, $expected, "file content ok";
+	is _ule $contents, _ule $expected, "file content ok";
 }
 
-sub test_big_file {
+sub test_big_file
+{
 	my ($name, $expected) = @_;
 
 	my $contents = _get_test_file_contents($name);
-	ok $contents eq $expected, "big file content ok";
+	ok _ule $contents eq _ule $expected, "big file content ok";
 }
 
-sub new_dies {
+sub new_dies
+{
 	my ($params, $message) = @_;
 
 	local $@;
